Learn R Programming

RAthena (version 1.5.0)

dbQuote: Quote Identifiers

Description

Call this method to generate string that is suitable for use in a query as a column or table name.

Usage

# S4 method for AthenaConnection,character
dbQuoteString(conn, x, ...)

# S4 method for AthenaConnection,SQL dbQuoteIdentifier(conn, x, ...)

Arguments

conn

A subclass of '>DBIConnection, representing an active connection to an DBMS.

x

A character vector to quote as string.

...

Other arguments passed on to methods.

Value

Returns a character object, for more information please check out: dbQuoteString, dbQuoteIdentifier

See Also

dbQuoteString, dbQuoteIdentifier